#!/bin/sh

set -e

DEBUILD="debuild"
# DISTRIB_CODENAME is xenial or trusty or precise
DISTRIB_CODENAME=$(sed -n "s/DISTRIB_CODENAME=//p" /etc/lsb-release)

if [ "$1" = "--help" ]; then
  echo "debuild wrapper script for hark-designer"
  echo "  Usage: $0 [--no-debuild | <debuild options>]"
  echo "  see also: debuild --help"
  exit 0
elif [ "$1" = "--no-debuild" ]; then
  DEBUILD="echo $DEBUILD"
fi


# current directory check
if [ ! -d "debian" ]; then
  echo "no debian directory here"
  exit 1
fi


# in case [precise] but [no libsdl2-dev]
#sdl_status=
SDL2BINPATH=$(which sdl2-config || true)
if [ ! -e "$SDL2BINPATH" ]; then
  if [ "${DISTRIB_CODENAME}" = "precise" ]; then 
    echo "***************************************"
    echo "# Please install libsdl2 packages"
    echo "# Do follows:"
    echo "     sudo add-apt-repository -y ppa:zoogie/sdl2-snapshots"
    echo "     sudo apt-get update"
    echo "     sudo apt-get -y install libsdl2-dev"
    echo ""
    echo "***************************************"
    exit 1
  else
    echo "***************************************"
    echo "# Please install libsdl2 packages"
    echo "     sudo apt-get install libsdl2-dev"
    echo "***************************************"
    exit 1
  fi
fi
echo "libsdl2 ok"


# change dependency for [libsdl2-dev]
rm -f debian/control 
ln -s "_control_${DISTRIB_CODENAME}" debian/control

${DEBUILD} "$@"
